*! version 1.0
* 22 April 2022
* CVACS Survey 2
* This do-file contains the code to create deflators to deflate CVACS Survey 2 financial data. 
* Deflated values can be generated by multiplying the relevant financial data variable by the deflator generated by this do-file.

*=====================================================================================================================================
/*

THIS DO FILE CREATES DEFLATORS FOR USE WITH THE CVACS DATASET.
BASE MONTH IS NOVEMBER 2021 AND INTERVIEW DATES ARE TAKEN FROM THE UNVACCINATED AND VACCINATED QUESTIONNAIRES. 
MISSING INTERVIEW MONTHS ARE IMPUTED TO THE MODAL MONTH FOR THE RELEVANT SURVEY.

PRICE INDICES ARE FROM THE NATIONAL HEADLINE CPI INDEX PUBLISHED BY STATS SA, AVAILABLE HERE:
http://www.statssa.gov.za/publications/P0141/CPIHistory.pdf?

*/
*=====================================================================================================================================

* GLOBALS FOR DATA FILES AND VERSION SUFFIXES
global CVS2DataIN "C:\Users\User\Desktop\Data"    			 //File path to where data is located. Change this path according to where your data folder in located on your computer.
global CVS2VerIN "S2_Anon_V1.0.0"

global DataOUT "C:\Users\User\Desktop\Data"
global VersionOUT "Derived"			

global temp "C:\Users\User\Desktop\Data"					// tempfile to hold all the working datasets, all working datasets will
															// be deleted from this folder at the completion of the do file execution.													

version 12.0												// version of Stata being used.

set more off

clear
cap clear matrix
set more off

scalar base=101.8  											//Set scalar to base month, March 2022.

*=====================================================================================================================================


* CVACS QUESTIONNAIRE
use "$CVS2DataIN\Unvaccinated_CVACS_$CVS2VerIN.dta", clear
keep pid s2_u_intrv_m
ren s2_u_intrv_m s2_intrv_m
tempfile unvaxed
save "`unvaxed'", replace

use "$CVS2DataIN\Vaccinated_CVACS_$CVS2VerIN.dta", clear
keep pid s2_v_intrv_m
ren s2_v_intrv_m s2_intrv_m

append using "`unvaxed'"

cap drop s2_deflator
gen s2_deflator=.
replace s2_deflator=base/100.8 if s2_intrv_m==2			// February 2022.
replace s2_deflator=base/101.8  if s2_intrv_m==3       		// March 2022.

lab var s2_deflator "CVACS Survey 2 deflator"

save "$DataOUT\CVACS_$VersionOUT.dta", replace

*=====================================================================================================================================

* end of do file


