*! version 1.0
* 22 April 2022
* CVACS
* Merging all survey datasets together.

/*  
NOTE TO USER
This do file merges all the CVACS datasets from all survey surveys. 

This do file assumes a parent folder (defined as global DataIN below) that 
contains separate subfolders for each survey, with the sub-folders being named 
"Survey `i'" where `i' is the survey number; E.g. "Survey 1"

*/
 
*===========================================================================================================================================
* GLOBALS FOR DATA FILES AND VERSION SUFFIXES

global DataIN "C:\Users\User\Desktop\Data" 		//File path to where data is located. Change this path according to where your data folder is located on your computer.

cd "$DataIN"

global num_surveys = 2								// This is the number of surveys in the panel

*===========================================================================================================================================

clear all
set more off
set maxvar 20000 

// Merging datasets together per survey

forvalues i = 1/$num_surveys {

	global VersionIN: dir "$DataIN\Survey `i'" files "Unvaccinated_CVACS_*.dta", respectcase
	global VersionIN: subinstr global VersionIN ".dta" "",all
	global VersionIN: subinstr global VersionIN "Unvaccinated_CVACS_" "",all
	global VersionIN: subinstr global VersionIN `"""' "",all
	
	cap {
		use "$DataIN\Survey `i'\Vaccinated_CVACS_$VersionIN.dta", clear
		ren s`i'_v_* s`i'_*
		gen datafile = "Vaccinated"
		tempfile vaxed
		save "`vaxed'", replace
	}
	
	use "$DataIN\Survey `i'\Unvaccinated_CVACS_$VersionIN.dta", clear
	ren s`i'_u_* s`i'_*
	gen datafile = "Unvaccinated"
	lab var datafile "Datafile"
	cap append using "`vaxed'"
	
	merge 1:1 pid using "$DataIN\Survey `i'\derived_CVACS_$VersionIN.dta"
	drop if _merge!=3
	drop _merge
	drop s`i'_outcome
	save survey`i'_merged_cv, replace
}

* Merging surveys to the Link    
use "$DataIN\Survey $num_surveys\Link_File_CVACS_$VersionIN.dta", clear

local save_name = "CVACS"

forvalues i = 1/$num_surveys {

	merge 1:1 pid using survey`i'_merged_cv
	drop _merge

	local save_name = "`save_name'" + "_" + "`i'"

}

save `save_name'.dta, replace

*===========================================================================================================================================
forvalues i = 1/$num_surveys {
	erase survey`i'_merged_cv.dta
}

*===========================================================================================================================================
*THE END
